
.. _magicbot_api:

magicbot module
----------------

.. module:: magicbot

.. automodule:: magicbot.magicrobot
    :members:
    :exclude-members: autonomous, disabled, members, operatorControl, robotInit, test
    :show-inheritance:

Component
~~~~~~~~~

.. automodule:: magicbot.magiccomponent
    :members:
    :undoc-members:
    :show-inheritance:

Tunable
~~~~~~~

.. automodule:: magicbot.magic_tunable
    :members:
    :undoc-members:
    :show-inheritance:

Resettable
~~~~~~~~~~

.. automodule:: magicbot.magic_reset
    :members:
    :undoc-members:
    :show-inheritance:

State machines
~~~~~~~~~~~~~~

.. automodule:: magicbot.state_machine
    :members:
    :exclude-members: members
    :undoc-members:
    :show-inheritance:
